@@ -9,19 +9,14 @@ use strict;
 
 sub fix_pgp_headers {
     my $item = shift;
-    my $item_body = $item->body;
-    my $body;
-
-    $body .= $_ foreach (@$item_body);
-
-    if ($body =~ /^-----BEGIN PGP MESSAGE-----/m and
-        $body =~ /^-----END PGP MESSAGE-----/m) {
+    if ($item->body =~ /^-----BEGIN PGP MESSAGE-----/ and
+        $item->body =~ /^-----END PGP MESSAGE-----/) {
         $item->put_header("Content-Type:", 
             "application/pgp; format=text; x-action=encrypt");
     }
-    if ($body =~ /^-----BEGIN PGP SIGNED MESSAGE-----/m and
-        $body =~ /^-----BEGIN PGP SIGNATURE-----/m and
-        $body =~ /^-----END PGP SIGNATURE-----/m) {
+    if ($item->body =~ /^-----BEGIN PGP SIGNED MESSAGE-----/ and
+        $item->body =~ /^-----BEGIN PGP SIGNATURE-----/ and
+        $item->body =~ /^-----END PGP SIGNATURE-----/) {
         $item->put_header("Content-Type:", 
             "application/pgp; format=text; x-action=sign");
     }
